<?php
/*
 *
 */

namespace Sikofitt\HathorBundle\Command;

use Symfony\Component\Finder\Finder;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Helper\ProgressBar;
use Symfony\Bundle\FrameworkBundle\Command\ContainerAwareCommand as BaseCommand;
use Sikofitt\HathorBundle\Common\Music\ID3;


class ScannerCommand extends BaseCommand
{

    protected function configure()
    {
        $this
            ->setName('hathor:scan')
            ->setDescription('Scans Music')
            ->addOption('directory', 'd', InputOption::VALUE_OPTIONAL, 'Directory to scan for music.',__DIR__)
            ->addArgument('extensions',InputArgument::IS_ARRAY, 'Extensions to scan for separated by a space',['mp2','mp3','mp4','wma','ogg']);

    }

    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $container = $this->getContainer();
        $em = $container->get('doctrine');

        $extensions = $input->getArgument('extensions');

        // \b(\.mp2|\.mp3|\.mp4|\.wma|\.ogg)\b$
        $extensionRegex = '/\b(';
        foreach($extensions as $extension) {
            $extensionRegex .= sprintf('\.%s|',$extension);
        }


        $extensionRegex[strlen($extensionRegex)-1] = ')';
        $extensionRegex .= '\b$/i';

        $output->writeln("\n Please wait ... finding files.\n");
        $finder = new Finder();
        $finder
            ->files()
            ->in($input->getOption('directory'))
            ->ignoreDotFiles(true)
            ->ignoreUnreadableDirs(true)
            ->name($extensionRegex);
        $progress = new ProgressBar($output, $finder->count());
        $cols = shell_exec('tput cols');
        $progress->setBarWidth($cols - 2);
        $format = [
            'barCharacter' => '<fg=cyan;options=bold>#</>',
            'progressCharacter' => '<fg=cyan>#</>',
            'emptyBarCharacter' => '<fg=cyan>#</>',
            'message' => '<fg=white;options=bold>%message%</>',
            'current' => '<fg=cyan>%current%</>',
            'currentMaxSep' => '<fg=black;options=bold>/</>',
            'max' => '<fg=cyan;options=bold>%max%</>',
            'percent' => '%percent:3s%%',
            'elapsed' => '%elapsed:6s%',
            'estimated' => '%estimated:-6s%',
            'elapsedEstimatedSep' => '/',
            'memory' => '%memory:6s%',
            'bar' => '<fg=cyan>[</>%bar%<fg=cyan>]</>',
        ];
        $format = (object)$format;
        $progress->setFormat("");
        $progress->clear();
        $progress->start();
        $getID3 = new ID3;
        $progress->setBarCharacter('<fg=cyan;options=bold>#</>');
        $progress->setProgressCharacter('<fg=cyan>#</>');
        $progress->setEmptyBarCharacter('<fg=cyan>#</>');
        //$progress->setRedrawFrequency(100);

        foreach ($finder as $file) {

            $fileLength = mb_strlen($file->getFilename());
            if($fileLength >= (int)$cols)
            {
                $fileName = substr($file->getFilename(), 0, (int)$cols -60);
            } else {
                $fileName =  $file->getFilename();
            }
//            $currentFile = str_pad($fileName . ' ...', ($cols - strlen(' ...')), ' ');
            $currentFile = $fileName;
            $progress->setMessage($currentFile);

            $getID3->setFile($file->getRealPath());
            try {

                $allMusicData[] = $getID3->getFileData ();
            } catch(\Exception $e) {
                $progress->setMessage('<warning>Caught RuntimeException</warning>');
                continue;
            }

            $progress->advance();

        }
        $progress->setMessage('Finished!');
        $progress->finish();
        $output->writeln('');
        //var_dump($allMusicData);



    }
}
